import request from '@/utils/request.js'

// 查询国际关键零部件模版列表
export function listTemplate(query) {
  return request({
    url: '/control/baseIntlPartTemplate/list',
    method: 'get',
    params: query
  })
}

// 新增国际关键零部件模版
export function addTemplate(data) {
  return request({
    url: '/control/baseIntlPartTemplate',
    method: 'post',
    data: data
  })
}

// 修改国际关键零部件模版
export function updateTemplate(data) {
  return request({
    url: '/control/baseIntlPartTemplate',
    method: 'put',
    data: data
  })
}

// 逻辑删除国际关键零部件模版
export function delLogicTemplate(id) {
  return request({
    url: '/control/baseIntlPartTemplate/logicDelete/' + id,
    method: 'delete'
  })
}

// 获取全部事业部
export function getAllUnit(data) {
  return request({
    url: '/control/baseIntlPartTemplate/getAllUnit/' + data,
    method: 'get'
  })
}

/** 下载二进制流文件
 * @param binFile 二进制文件流
 * @param fileName 文件名，例如：测试文本.txt
 * @param blobType Blob 对象的 type 属性给出文件的 MIME 类型，默认：'application/octet-stream'(用于通用二进制数据)
 */
export function downloadBinaryFile(binFile, fileName, blobType = 'application/octet-stream')
{
  // 处理二进制数据并创建 Blob 对象
  const blobObj = new Blob([binFile], {type: blobType})
  // 创建一个链接并设置下载属性
  const downloadLink = document.createElement('a')
  let url = window.URL || window.webkitURL || window.moxURL // 兼容不同浏览器的 URL 对象
  url = url.createObjectURL(blobObj)
  downloadLink.href = url
  downloadLink.download = fileName // 设置下载的文件名
  // 将链接添加到 DOM 中，模拟点击
  document.body.appendChild(downloadLink)
  downloadLink.click()
  // 移除创建的链接和释放 URL 对象
  document.body.removeChild(downloadLink)
  window.URL.revokeObjectURL(url)
}
